@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #define ABOUT_H
 
 #include "ui_about.h"
-#include <QtGui/QDialog>
+#include <QDialog>
 
 class About : public QDialog
 {
@@ -29,9 +29,11 @@ class About : public QDialog
 public:
     About(QWidget *parent = 0);
     void retranslateUi();
+    void setLanguage(const QString lang) { m_lang = lang; }
 
 private:
     Ui::AboutClass ui;
+    QString m_lang;
 };
 
 #endif // ABOUT_H
