@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 #define KEYBOARDMAP_H
 
 #include "constants.h"
-#include <QtCore/QHash>
-#include <QtCore/QIODevice>
+#include <QHash>
+#include <QIODevice>
 
 class KeyboardMap : public QHash<int, int>
 {
