@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,11 +18,11 @@
 
 #include "kmapdialog.h"
 #include "vpiano.h"
-#include <QtCore/QFileInfo>
-#include <QtGui/QHeaderView>
-#include <QtGui/QPushButton>
-#include <QtGui/QKeySequence>
-#include <QtGui/QFileDialog>
+#include <QFileInfo>
+#include <QHeaderView>
+#include <QPushButton>
+#include <QKeySequence>
+#include <QFileDialog>
 
 KMapDialog::KMapDialog(QWidget *parent)
     : QDialog(parent)
@@ -97,11 +97,15 @@ void KMapDialog::slotOpen()
 
 void KMapDialog::slotSave()
 {
-    QString fileName = QFileDialog::getSaveFileName(this,
-                                tr("Save keyboard map definition"),
-                                VPiano::dataDirectory(),
-                                tr("Keyboard map (*.xml)"));
-    if (!fileName.isEmpty()) {
+    QFileDialog dlg(this);
+    dlg.setNameFilter(tr("Keyboard map (*.xml)"));
+    dlg.setDirectory(VPiano::dataDirectory());
+    dlg.setWindowTitle(tr("Save keyboard map definition"));
+    dlg.setDefaultSuffix("xml");
+    dlg.setFileMode(QFileDialog::AnyFile);
+    dlg.setAcceptMode(QFileDialog::AcceptSave);
+    if (dlg.exec() == QDialog::Accepted) {
+        QString fileName = dlg.selectedFiles().first();
         updateMap();
         m_map.saveToXMLFile(fileName);
     }
