@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,42 +16,35 @@
     with this program; If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <QApplication>
+#include <QSplashScreen>
+#include <QThread>
+#include <QTimer>
 #include "constants.h"
 #include "vpiano.h"
-#if defined(RAWKBD_SUPPORT)
-#include "rawkeybdapp.h"
-#endif
-#include <QtGui/QApplication>
-#if defined(Q_OS_SYMBIAN)
-// to lock orientation in Symbian
-#include <eikenv.h>
-#include <eikappui.h>
-#include <aknenv.h>
-#include <aknappui.h>
-#endif
 
 int main(int argc, char *argv[])
 {
     QCoreApplication::setOrganizationName(QSTR_DOMAIN);
     QCoreApplication::setOrganizationDomain(QSTR_DOMAIN);
     QCoreApplication::setApplicationName(QSTR_APPNAME);
-#if defined(RAWKBD_SUPPORT)
-    RawKeybdApp a(argc, argv);
-#else
-    QApplication a(argc, argv);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
+    QCoreApplication::setAttribute(Qt::AA_SynthesizeMouseForUnhandledTouchEvents, false);
+    QCoreApplication::setAttribute(Qt::AA_SynthesizeTouchForUnhandledMouseEvents, false);
+    QApplication a(argc, argv);
 #if defined(Q_OS_LINUX)
     a.setWindowIcon(QIcon(":/vpiano/vmpk_32x32.png"));
 #endif //Q_OS_LINUX
-#if defined(Q_OS_SYMBIAN)
-    // Lock orientation to portrait in Symbian
-    CAknAppUi* appUi = dynamic_cast<CAknAppUi*> (CEikonEnv::Static()->AppUi());
-    TRAP_IGNORE(
-        if(appUi) {
-            appUi->SetOrientationL(CAknAppUi::EAppUiOrientationLandscape);
-        }
-    );
-#endif //Q_OS_SYMBIAN
+    QPixmap px(":/vpiano/vmpk_splash.png");
+    QSplashScreen s(px);
+    QFont sf("Arial", 20, QFont::ExtraBold);
+    s.setFont(sf);
+    s.show();
+    s.showMessage("Virtual MIDI Piano Keyboard " + PGM_VERSION, Qt::AlignBottom | Qt::AlignRight);
+    QTimer::singleShot(2500, &s, SLOT(close()));
+    a.processEvents();
     VPiano w;
     if (w.isInitialized()) {
 #if defined(SMALL_SCREEN)
