@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,8 +19,12 @@
 #ifndef MIDISETUP_H
 #define MIDISETUP_H
 
+#include <QDialog>
+#include <drumstick/rtmidiinput.h>
+#include <drumstick/rtmidioutput.h>
 #include "ui_midisetup.h"
-#include <QtGui/QDialog>
+
+using namespace drumstick::rt;
 
 class MidiSetup : public QDialog
 {
@@ -31,26 +35,42 @@ public:
     void inputNotAvailable();
     bool inputIsEnabled() const;
     bool thruIsEnabled() const;
+    bool omniIsEnabled() const;
     void setInputEnabled(const bool state);
     void setThruEnabled(const bool state);
+    void setOmniEnabled(const bool state);
     void clearCombos();
-    void addInputPortName(const QString& name, int index);
-    void addOutputPortName(const QString& output, int index);
-    void setCurrentInput(int index);
-    void setCurrentInput(const QString name);
-    void setCurrentOutput(int index);
-    void setCurrentOutput(const QString name);
-    int  selectedInput();
-    int  selectedOutput();
-    QString selectedInputName() const;
-    QString selectedOutputName() const;
     void retranslateUi();
 
+    void setInput(MIDIInput *in) { m_midiIn = in; }
+    void setOutput(MIDIOutput *out) { m_midiOut = out; }
+    void setInputs(QList<MIDIInput *> ins);
+    void setOutputs(QList<MIDIOutput *> outs);
+    MIDIInput *getInput() { return m_midiIn; }
+    MIDIOutput *getOutput() { return m_midiOut; }
+    void setAdvanced(bool value);
+    bool advanced();
+    bool midiThru();
+    bool changeSoundFont(const QString& fileName);
+
 public slots:
+    void clickedAdvanced(bool value);
+    void setMidiThru(bool value);
     void toggledInput(bool state);
+    void refreshInputs(QString id);
+    void refreshOutputs(QString id);
+    void configureInput();
+    void configureOutput();
+    void refresh();
+    void accept();
 
 private:
+    bool m_advanced;
+    bool m_thru;
+    bool m_settingsChanged;
     Ui::MidiSetupClass ui;
+    MIDIInput* m_midiIn;
+    MIDIOutput* m_midiOut;
 };
 
 #endif /* MIDISETUP_H */
