@@ -1,6 +1,6 @@
 /*
     Virtual Piano Widget for Qt4 
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,25 +22,25 @@ PianoKeybd::PianoKeybd(QWidget *parent)
     : QGraphicsView(parent), m_rotation(0), m_scene(NULL), m_rawMap(NULL)
 {
     initialize();
-    initScene(3, 5);
+    initScene(DEFAULTBASEOCTAVE, DEFAULTNUMBEROFKEYS, DEFAULTSTARTINGKEY);
 }
 
-PianoKeybd::PianoKeybd(const int baseOctave, const int numOctaves, QWidget *parent) 
+PianoKeybd::PianoKeybd(const int baseOctave, const int numKeys, const int startKey, QWidget *parent)
     : QGraphicsView(parent), m_rotation(0), m_scene(NULL), m_rawMap(NULL)
 {
     initialize();
-    initScene(baseOctave, numOctaves);
+    initScene(baseOctave, numKeys, startKey);
 }
 
 PianoKeybd::~PianoKeybd()
 {
-    setRawKeyboardMode(false);
-    setRawKeyboardMap(NULL);
+    m_scene->setRawKeyboardMode(false);
+    setRawKeyboardMap(0);
 }
 
-void PianoKeybd::initScene(int base, int num, const QColor& c)
+void PianoKeybd::initScene(int base, int num, int strt, const QColor& c)
 {
-    m_scene = new PianoScene(base, num, c, this);
+    m_scene = new PianoScene(base, num, strt, c, this);
     m_scene->setKeyboardMap(&m_defaultMap);
     connect(m_scene, SIGNAL(noteOn(int,int)), SIGNAL(noteOn(int,int)));
     connect(m_scene, SIGNAL(noteOff(int,int)), SIGNAL(noteOff(int,int)));
@@ -61,12 +61,6 @@ void PianoKeybd::initialize()
     setOptimizationFlag(DontAdjustForAntialiasing, true);
     setBackgroundBrush(QApplication::palette().background());
     initDefaultMap();
-#if defined(RAWKBD_SUPPORT)
-    RawKeybdApp* rapp = dynamic_cast<RawKeybdApp*>(qApp);
-    if (rapp != NULL) {
-        rapp->setRawKbdHandler(this);
-    }
-#endif
 }
 
 void PianoKeybd::resizeEvent(QResizeEvent *event)
@@ -75,16 +69,6 @@ void PianoKeybd::resizeEvent(QResizeEvent *event)
     fitInView(m_scene->sceneRect(), Qt::KeepAspectRatio);
 }
 
-void PianoKeybd::showNoteOn(int midiNote, int vel)
-{
-    m_scene->showNoteOn(midiNote, vel);
-}
-
-void PianoKeybd::showNoteOff(int midiNote, int vel)
-{
-    m_scene->showNoteOff(midiNote, vel);
-}
-
 void PianoKeybd::initDefaultMap()
 {
     // Default translated Keyboard Map
@@ -119,7 +103,7 @@ void PianoKeybd::initDefaultMap()
     m_defaultMap.insert(Qt::Key_P, 40);
 
     // Default Raw Keyboard Map
-#if defined(Q_WS_X11)
+#if defined(Q_OS_LINUX)
     m_defaultRawMap.insert(94, 11);
     m_defaultRawMap.insert(52, 12);
     m_defaultRawMap.insert(39, 13);
@@ -161,7 +145,7 @@ void PianoKeybd::initDefaultMap()
     m_defaultRawMap.insert(35, 48);
 #endif
 
-#if defined(Q_WS_WIN)
+#if defined(Q_OS_WIN)
     m_defaultRawMap.insert(86, 11);
     m_defaultRawMap.insert(44, 12);
     m_defaultRawMap.insert(31, 13);
@@ -203,7 +187,7 @@ void PianoKeybd::initDefaultMap()
     m_defaultRawMap.insert(27, 48);
 #endif
 
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
     m_defaultRawMap.insert(50, 11);
     m_defaultRawMap.insert(6, 12);
     m_defaultRawMap.insert(1, 13);
@@ -247,17 +231,24 @@ void PianoKeybd::initDefaultMap()
     m_rawMap = &m_defaultRawMap;
 }
 
-void PianoKeybd::setNumOctaves(const int numOctaves)
+void PianoKeybd::setNumKeys(const int numKeys, const int startKey)
 {
-    if (numOctaves != m_scene->numOctaves()) {
+    if ( numKeys != m_scene->numKeys() || startKey != m_scene->startKey() )
+    {
         int baseOctave = m_scene->baseOctave();
         QColor color = m_scene->getKeyPressedColor();
         PianoHandler* handler = m_scene->getPianoHandler();
         KeyboardMap* keyMap = m_scene->getKeyboardMap();
+        bool keyboardEnabled = m_scene->isKeyboardEnabled();
+        bool mouseEnabled = m_scene->isMouseEnabled();
+        bool touchEnabled = m_scene->isTouchEnabled();
         delete m_scene;
-        initScene(baseOctave, numOctaves, color);
+        initScene(baseOctave, numKeys, startKey, color);
         m_scene->setPianoHandler(handler);
         m_scene->setKeyboardMap(keyMap);
+        m_scene->setKeyboardEnabled(keyboardEnabled);
+        m_scene->setMouseEnabled(mouseEnabled);
+        m_scene->setTouchEnabled(touchEnabled);
         fitInView(m_scene->sceneRect(), Qt::KeepAspectRatio);
     }
 }
@@ -280,7 +271,7 @@ QSize PianoKeybd::sizeHint() const
 #if defined(RAWKBD_SUPPORT)
 bool PianoKeybd::handleKeyPressed(int keycode)
 {
-    if (m_rawMap != NULL && m_rawMap->contains(keycode)) {
+    if (m_scene->isKeyboardEnabled() && m_rawMap != NULL && m_rawMap->contains(keycode)) {
         m_scene->keyOn(m_rawMap->value(keycode));
         return true;
     }
@@ -289,15 +280,10 @@ bool PianoKeybd::handleKeyPressed(int keycode)
 
 bool PianoKeybd::handleKeyReleased(int keycode)
 {
-    if (m_rawMap != NULL && m_rawMap->contains(keycode)) {
+    if (m_scene->isKeyboardEnabled() && m_rawMap != NULL && m_rawMap->contains(keycode)) {
         m_scene->keyOff(m_rawMap->value(keycode));
         return true;
     }
     return false;
 }
 #endif
-
-void PianoKeybd::retranslate()
-{
-    m_scene->retranslate();
-}
