@@ -1,6 +1,6 @@
 /*
     Virtual Piano Widget for Qt4 
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,9 +21,10 @@
 
 #include "pianoscene.h"
 #if defined(RAWKBD_SUPPORT)
-#include "rawkeybdapp.h"
+//#include "rawkeybdapp.h"
+#include "nativefilter.h"
 #endif
-#include <QtGui/QGraphicsView>
+#include <QGraphicsView>
 
 #if defined(VPIANO_PLUGIN)
 #include <QtDesigner/QDesignerExportWidget>
@@ -38,7 +39,7 @@ class QDESIGNER_WIDGET_EXPORT PianoKeybd : public QGraphicsView
 {
     Q_OBJECT
     Q_PROPERTY( int baseOctave READ baseOctave WRITE setBaseOctave )
-    Q_PROPERTY( int numOctaves READ numOctaves WRITE setNumOctaves )
+    Q_PROPERTY( int numKeys READ numKeys WRITE setNumKeys )
     Q_PROPERTY( int rotation READ getRotation WRITE setRotation )
     Q_PROPERTY( QColor keyPressedColor READ getKeyPressedColor WRITE setKeyPressedColor )
     Q_PROPERTY( bool showLabels READ showLabels WRITE setShowLabels )
@@ -51,51 +52,37 @@ class QDESIGNER_WIDGET_EXPORT PianoKeybd : public QGraphicsView
 #endif
 public:
     PianoKeybd(QWidget *parent = 0);
-    PianoKeybd(const int baseOctave, const int numOctaves, QWidget *parent = 0);
+    PianoKeybd(const int baseOctave, const int numKeys, const int startKey, QWidget *parent = 0);
     virtual ~PianoKeybd();
-    void setKeyboardMap(KeyboardMap* m) { m_scene->setKeyboardMap(m); }
-    void resetKeyboardMap() { m_scene->setKeyboardMap(&m_defaultMap); }
-    KeyboardMap* getKeyboardMap() { return m_scene->getKeyboardMap(); }
-    void setRawKeyboardMap(KeyboardMap* m) { m_rawMap = m; }
-    KeyboardMap* getRawKeyboardMap() { return m_rawMap; }
-    void resetRawKeyboardMap() { m_rawMap = &m_defaultRawMap; }
 
     int baseOctave() const { return m_scene->baseOctave(); }
-    int numOctaves() const { return m_scene->numOctaves(); }
     void setBaseOctave(const int baseOctave) { m_scene->setBaseOctave(baseOctave); }
-    void setNumOctaves(const int numOctaves);
-    QSize sizeHint() const;
+    int numKeys() const { return m_scene->numKeys(); }
+    int startKey() const { return m_scene->startKey(); }
+    void setNumKeys(const int numKeys, const int startKey = DEFAULTSTARTINGKEY);
     int getRotation() const { return m_rotation; }
     void setRotation(int r);
     QColor getKeyPressedColor() const { return m_scene->getKeyPressedColor(); }
     void setKeyPressedColor(const QColor& c) { m_scene->setKeyPressedColor(c); }
-    void allKeysOff() { m_scene->allKeysOff(); }
-    void setPianoHandler(PianoHandler* handler) { m_scene->setPianoHandler(handler); }
-    int minNote() const { return m_scene->getMinNote(); }
-    void setMinNote(int n) { m_scene->setMinNote(n); }
-    int maxNote() const { return m_scene->getMaxNote(); }
-    void setMaxNote(int n) { m_scene->setMaxNote(n); }
-    int getTranspose() const { return m_scene->getTranspose(); }
-    void setTranspose(int t) { m_scene->setTranspose(t); }
     bool showLabels() const { return m_scene->showLabels(); }
     void setShowLabels(bool show) { m_scene->setShowLabels(show); }
     bool useFlats() const { return m_scene->useFlats(); }
     void setUseFlats(bool use) { m_scene->setUseFlats(use); }
-    bool getRawKeyboardMode() const { return m_scene->getRawKeyboardMode(); }
-    void setRawKeyboardMode(const bool b) { m_scene->setRawKeyboardMode(b); }
-    void useCustomNoteNames(const QStringList& names) { m_scene->useCustomNoteNames(names); }
-    void useStandardNoteNames() { m_scene->useStandardNoteNames(); }
-    int getVelocity() { return m_scene->getVelocity(); }
-    void setVelocity(const int velocity) { m_scene->setVelocity(velocity); }
-    void retranslate();
+    int getTranspose() const { return m_scene->getTranspose(); }
+    void setTranspose(int t) { m_scene->setTranspose(t); }
+
+    QSize sizeHint() const;
+    PianoScene* getPianoScene() { return m_scene; }
+    void setRawKeyboardMap(KeyboardMap* m) { m_rawMap = m; }
+    KeyboardMap* getRawKeyboardMap() { return m_rawMap; }
+    void resetRawKeyboardMap() { m_rawMap = &m_defaultRawMap; }
+    void resetKeyboardMap() { m_scene->setKeyboardMap(&m_defaultMap); }
+
 #if defined(RAWKBD_SUPPORT)
 // RawKbdHandler methods
     bool handleKeyPressed(int keycode);
     bool handleKeyReleased(int keycode);
 #endif
-public slots:
-    void showNoteOn( int midiNote, int vel = -1 );
-    void showNoteOff( int midiNote, int vel = -1 );
 
 signals:
     void noteOn( int midiNote, int vel );
@@ -104,7 +91,7 @@ signals:
 protected:
     void initialize();
     void initDefaultMap();
-    void initScene(int base, int num, const QColor& c = QColor());
+    void initScene(int base, int num, int ini, const QColor& c = QColor());
     void resizeEvent(QResizeEvent *event);
 
 private:
