@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,9 @@
 #include "ui_preferences.h"
 #include "instrument.h"
 #include "keyboardmap.h"
-#include <QtGui/QDialog>
+#include <QDialog>
+
+class ColorDialog;
 
 class Preferences : public QDialog
 {
@@ -30,15 +32,17 @@ class Preferences : public QDialog
 
 public:
     Preferences(QWidget *parent = 0);
-    int getNumOctaves() const { return m_numOctaves; }
+    int getNumKeys() const { return m_numKeys; }
     int getDrumsChannel() const { return m_drumsChannel; }
-    int getNetworkPort() const { return m_networkPort; }
-    QColor getKeyPressedColor() const { return m_keyPressedColor; }
-    bool getGrabKeyboard() const { return m_grabKb; }
-    bool getStyledWidgets() const { return m_styledKnobs; }
+    int getStartingKey() const { return m_startingKey; }
     bool getAlwaysOnTop() const { return m_alwaysOnTop; }
     bool getRawKeyboard() const { return m_rawKeyboard; }
     bool getVelocityColor() const { return m_velocityColor; }
+    bool getEnforceChannelState() const { return m_enforceChannelState; }
+    bool getEnabledKeyboard() const { return m_enableKeyboard; }
+    bool getEnabledMouse() const { return m_enableMouse; }
+    bool getEnabledTouch() const { return m_enableTouch; }
+
     void setInstrumentsFileName( const QString fileName );
     QString getInstrumentsFileName();
     void setInstrumentName( const QString name );
@@ -51,17 +55,20 @@ public:
     KeyboardMap* getKeyboardMap() { return &m_keymap; }
     KeyboardMap* getRawKeyboardMap() { return &m_rawmap; }
     void retranslateUi();
+    void setColorPolicyDialog(ColorDialog *value);
+    void setNoteNames(const QStringList& noteNames);
 
 public slots:
-    void setNumOctaves(int value) { m_numOctaves = value; }
+    void setNumKeys(int value) { m_numKeys = value; }
     void setDrumsChannel(int value) { m_drumsChannel = value; }
-    void setNetworkPort(int value) { m_networkPort = value; }
-    void setGrabKeyboard(bool value) { m_grabKb = value; }
-    void setStyledWidgets(bool value) { m_styledKnobs = value; }
+    void setStartingKey(int value) { m_startingKey = value; }
     void setAlwaysOnTop(bool value) { m_alwaysOnTop = value; }
     void setRawKeyboard(bool value) { m_rawKeyboard = value; }
     void setVelocityColor(bool value) { m_velocityColor = value; }
-    void setKeyPressedColor(QColor value);
+    void setEnforceChannelState(bool value) { m_enforceChannelState = value; }
+    void setEnabledKeyboard(bool value) { m_enableKeyboard = value; }
+    void setEnabledMouse(bool value) { m_enableMouse = value; }
+    void setEnabledTouch(bool value) { m_enableTouch = value; }
     void slotOpenInstrumentFile();
     void slotSelectColor();
     void slotOpenKeymapFile();
@@ -77,17 +84,19 @@ private:
     Ui::PreferencesClass ui;
     QString m_insFileName;
     InstrumentList m_ins;
-    int m_numOctaves;
+    int m_numKeys;
     int m_drumsChannel;
-    int m_networkPort;
-    bool m_grabKb;
-    bool m_styledKnobs;
+    int m_startingKey;
     bool m_alwaysOnTop;
     bool m_rawKeyboard;
     bool m_velocityColor;
-    QColor m_keyPressedColor;
+    bool m_enforceChannelState;
+    bool m_enableKeyboard;
+    bool m_enableMouse;
+    bool m_enableTouch;
     KeyboardMap m_keymap;
     KeyboardMap m_rawmap;
+    ColorDialog* m_colorDialog;
 };
 
 #endif // PREFERENCES_H
