@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,11 @@
     with this program; If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QFile>
-#include <QtCore/QTextStream>
-#include <QtGui/QFileDialog>
-#include <QtGui/QDesktopServices>
+#include <QFileInfo>
+#include <QFile>
+#include <QTextStream>
+#include <QFileDialog>
+#include <QDesktopServices>
 
 #include "riffimportdlg.h"
 #include "ui_riffimportdlg.h"
@@ -55,10 +55,18 @@ void RiffImportDlg::openInput()
 
 void RiffImportDlg::openOutput()
 {
-    QString fileName = QFileDialog::getSaveFileName(this,
-        tr("Output"), m_output, tr("Instrument definitions (*.ins)"));
-    if (!fileName.isEmpty())
+    QFileDialog dlg(this);
+    dlg.setNameFilter(tr("Instrument definitions (*.ins)"));
+    dlg.setWindowTitle(tr("Output"));
+    dlg.setDefaultSuffix("ins");
+    dlg.setDirectory(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
+    dlg.selectFile(m_output);
+    dlg.setFileMode(QFileDialog::AnyFile);
+    dlg.setAcceptMode(QFileDialog::AcceptSave);
+    if (dlg.exec() == QFileDialog::Accepted) {
+        QString fileName = dlg.selectedFiles().first();
         setOutput(fileName);
+    }
 }
 
 void RiffImportDlg::setInput(QString fileName)
@@ -66,11 +74,7 @@ void RiffImportDlg::setInput(QString fileName)
     QFileInfo f(fileName);
     if (f.exists()) {
         ui->m_input->setText(m_input = fileName);
-#if QT_VERSION < 0x040400
-        QDir dir = QDir::home();
-#else
-        QDir dir = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation);
-#endif
+        QDir dir = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
         QString fullFilespec = dir.absoluteFilePath(f.baseName() + ".ins");
         setOutput(fullFilespec);
     }
