@@ -1,7 +1,7 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
-    Copyright (C) 2005-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -55,8 +55,8 @@ public:
 		{ return m_sDefaultText; }
 
 signals:
-
 	void editingFinished();
+    void valueChanged(QString text);
 
 protected slots:
 
@@ -122,11 +122,13 @@ public:
 	// Constructor.
 	ShortcutDialog(QList<QAction *> actions, QWidget *pParent = NULL);
     void retranslateUi();
+    void setDefaultShortcuts(QHash<QString,QList<QKeySequence> > &defs);
 
 protected slots:
 
 	void actionActivated(QTableWidgetItem *);
 	void actionChanged(QTableWidgetItem *);
+    void slotRestoreDefaults();
 
 	void accept();
 	void reject();
@@ -137,8 +139,8 @@ private:
 	Ui::ShortcutDialog m_ui;
 
 	QList<QAction *> m_actions;
-
-	int m_iDirtyCount;
+    QHash<QString,QList<QKeySequence> > m_defaultShortcuts;
+    int m_iDirtyCount;
 };
 
 
