@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2011, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,24 +21,32 @@
 
 #include "ui_vpiano.h"
 #include "pianoscene.h"
-#include <QtGui/QMainWindow>
+#if defined(RAWKBD_SUPPORT)
+#include "nativefilter.h"
+#endif
+#include <QMainWindow>
 
 class QTranslator;
 class QLabel;
 class QComboBox;
 class QSpinBox;
 class QSlider;
-class QStyle;
-class Knob;
+class QDial;
 class Instrument;
-class RtMidiIn;
-class RtMidiOut;
 class About;
 class Preferences;
 class MidiSetup;
 class KMapDialog;
 class DialogExtraControls;
 class RiffImportDlg;
+class ColorDialog;
+
+namespace drumstick {
+namespace rt {
+    class MIDIInput;
+    class MIDIOutput;
+    class BackendManager;
+}}
 
 class VPiano : public QMainWindow, public PianoHandler
 {
@@ -47,8 +55,6 @@ class VPiano : public QMainWindow, public PianoHandler
 public:
     VPiano( QWidget * parent = 0, Qt::WindowFlags flags = 0 );
     virtual ~VPiano();
-    int getInputChannel();
-    void midiThru(std::vector<unsigned char> *message) const;
     bool isInitialized() const { return m_initialized; }
     void retranslateUi();
     QMenu *createPopupMenu ();
@@ -134,12 +140,26 @@ protected Q_SLOTS:
     void slotControllerUp();
     void slotControllerDown();
     void slotSwitchLanguage(QAction *action);
+    void slotKeyboardInput(bool value);
+    void slotMouseInput(bool value);
+    void slotTouchScreenInput(bool value);
+    void slotColorPolicy();
+    void slotColorScale(bool value);
     //void slotEditPrograms();
     //void slotDebugDestroyed(QObject *obj);
 
+    //drumstick-rt slots
+    void slotNoteOn(const int chan, const int note, const int vel);
+    void slotNoteOff(const int chan, const int note, const int vel);
+    void slotKeyPressure(const int chan, const int note, const int value);
+    void slotController(const int chan, const int control, const int value);
+    void slotProgram(const int chan, const int program);
+    void slotChannelPressure(const int chan, const int value);
+    void slotPitchBend(const int chan, const int value);
+    void toggleWindowFrame(const bool state);
+
 protected:
     void closeEvent ( QCloseEvent *event );
-    void customEvent ( QEvent *event );
     void showEvent ( QShowEvent *event );
     void hideEvent( QHideEvent *event );
 
@@ -147,10 +167,12 @@ private:
     void initialization();
     bool initMidi();
     void readSettings();
+    void readMidiControllerSettings();
     void writeSettings();
     void applyPreferences();
     void applyConnections();
     void applyInitialSettings();
+    void applyColorPolicy();
     void populateControllers();
     void populateInstruments();
     void populatePrograms(int bank = -1);
@@ -171,19 +193,23 @@ private:
     void sendPolyKeyPress(const int note, const int value);
     void sendChanKeyPress(const int value);
     void sendSysex(const QByteArray& data);
-    void sendMessageWrapper(std::vector<unsigned char> *message) const;
     void updateController(int ctl, int val);
     void updateExtraController(int ctl, int val);
     void updateBankChange(int bank = -1);
     void updateProgramChange(int program = -1);
     void grabKb();
     void releaseKb();
-    void updateStyles();
     void updateNoteNames(bool drums);
     void setWidgetTip(QWidget* w, int val);
+
     QByteArray readSysexDataFile(const QString& fileName);
     void createLanguageMenu();
     QString configuredLanguage();
+    void enforceMIDIChannelState();
+    QColor getColorFromPolicy(const int chan, const int note, const int vel);
+    int getType(const int note) const;
+    int getDegree(const int note) const;
+    PianoScene *currentPianoScene();
 
     About *dlgAbout();
     Preferences *dlgPreferences();
@@ -191,16 +217,18 @@ private:
     KMapDialog *dlgKeyMap();
     DialogExtraControls *dlgExtra();
     RiffImportDlg *dlgRiffImport();
+    ColorDialog *dlgColorPolicy();
 
     void initLanguages();
     void retranslateToolbars();
 
-    RtMidiOut* m_midiout;
-    RtMidiIn* m_midiin;
-    int m_currentOut;
-    int m_currentIn;
+    drumstick::rt::MIDIOutput* m_midiout;
+    drumstick::rt::MIDIInput* m_midiin;
+    drumstick::rt::BackendManager* m_backendManager;
+
     bool m_inputActive;
     bool m_midiThru;
+    bool m_midiOmni;
     bool m_initialized;
 
     About *m_dlgAbout;
@@ -209,6 +237,10 @@ private:
     KMapDialog *m_dlgKeyMap;
     DialogExtraControls *m_dlgExtra;
     RiffImportDlg *m_dlgRiffImport;
+    ColorDialog *m_dlgColorPolicy;
+#if defined(RAWKBD_SUPPORT)
+    NativeFilter *m_filter;
+#endif
 
     Ui::VPiano ui;
 
@@ -224,20 +256,19 @@ private:
     QSpinBox* m_sboxChannel;
     QSpinBox* m_sboxOctave;
     QSpinBox* m_sboxTranspose;
-    Knob* m_Velocity;
+    QDial* m_Velocity;
     QComboBox* m_comboControl;
-    Knob* m_Control;
+    QDial* m_Control;
     QSlider* m_bender;
     QComboBox* m_comboBank;
     QComboBox* m_comboProg;
-    QStyle* m_dialStyle;
     Instrument* m_ins;
     QStringList m_extraControls;
     QMap<int,QMap<int,int> > m_ctlState, m_ctlSettings;
     QMap<int,int> m_lastBank;
     QMap<int,int> m_lastProg;
     QMap<int,int> m_lastCtl;
-    int m_channel;
+    int m_baseChannel;
     int m_velocity;
     int m_baseOctave;
     int m_transpose;
@@ -245,6 +276,19 @@ private:
     QMap<QString, QString> m_supportedLangs;
     QTranslator *m_trq, *m_trp;
     QAction *m_currentLang;
+    QHash<QString,QList<QKeySequence> > m_defaultShortcuts;
+    int m_currentPalette;
+
+    QString m_lastInputBackend;
+    QString m_lastOutputBackend;
+    QString m_lastInputConnection;
+    QString m_lastOutputConnection;
+    QString m_defaultInputBackend;
+    QString m_defaultOutputBackend;
+    QString m_defaultInputConnection;
+    QString m_defaultOutputConnection;
+    bool m_advanced;
+    bool m_inputEnabled;
 };
 
 #endif // VPIANO_H
